@@ -28,14 +28,23 @@ except ModuleNotFoundError:  # pragma: no cover
 __version__ = importlib_metadata.version(__name__.replace(".", "-"))
 
 from ansys.mapdl.core import examples
+from ansys.mapdl.core._version import SUPPORTED_ANSYS_VERSIONS
 from ansys.mapdl.core.convert import convert_apdl_block, convert_script
 from ansys.mapdl.core.launcher import (
     change_default_ansys_path,
     close_all_local_instances,
     find_ansys,
     get_ansys_path,
-    launch_mapdl,
+    get_available_ansys_installations,
+    save_ansys_path,
 )
+
+# override default launcher when on pyansys.com
+if "ANSJUPHUB_VER" in os.environ:  # pragma: no cover
+    from ansys.mapdl.core.jupyter import launch_mapdl_on_cluster as launch_mapdl
+else:
+    from ansys.mapdl.core.launcher import launch_mapdl
+
 from ansys.mapdl.core.mapdl_grpc import MapdlGrpc as Mapdl
 from ansys.mapdl.core.misc import Information, Report, _check_has_ansys
 from ansys.mapdl.core.pool import LocalMapdlPool
@@ -56,10 +65,4 @@ try:
 except:  # pragma: no cover
     pass
 
-
-# override default launcher when on pyansys.com
-if "ANSJUPHUB_VER" in os.environ:
-    from ansys.mapdl.core.jupyter import launch_mapdl_on_cluster as launch_mapdl
-
-
 BUILDING_GALLERY = False
