@@ -14,24 +14,24 @@ class Special:
 
         ia, ib
             Reference numbers of the two variables to be operated on.  If only
-            one, leave IB blank.
+            one, leave ``IB`` blank.
 
         itype
             Defines the type of response PSD to be calculated:
 
-            0,1 - Displacement (default).
+            * ``0,1`` - Displacement (default).
 
-            2 - Velocity.
+            * ``2`` - Velocity.
 
-            3 - Acceleration.
+            * ``3`` - Acceleration.
 
         datum
             Defines the reference with respect to which covariance is to be
             calculated:
 
-            1 - Absolute value.
+            * ``1`` - Absolute value.
 
-            2 - Relative to base (default).
+            * ``2`` - Relative to base (default).
 
         name
             Thirty-two character name for identifying the variable on listings
@@ -72,8 +72,8 @@ class Special:
         fname
             File name (8 characters maximum) to which tabular data and plot
             files will be written.  Must be enclosed in single quotes when the
-            command is manually typed in.  Defaults to MG_TRNS.  The data file
-            extension is .OUT and the plot file extension is .PLT.
+            command is manually typed in.  Defaults to ``MG_TRNS``.  The data file
+            extension is ``.OUT`` and the plot file extension is ``.PLT``.
 
         freq
             Frequency of solution output.  Defaults to 1.  Every FREQth
@@ -94,16 +94,16 @@ class Special:
 
         Notes
         -----
-        PMGTRAN invokes an ANSYS macro which calculates and summarizes
+        ``PMGTRAN`` invokes an ANSYS macro which calculates and summarizes
         electromagnetic results from a transient analysis.  The results are
         summarized by element components and listed on the screen as well as
-        written to a file (Fname.OUT).  Also, graph plots of results as a
-        function of time are created and written to a file (Fname.PLT) for use
-        in the DISPLAY program.
+        written to a file (``Fname.OUT``).  Also, graph plots of results as a
+        function of time are created and written to a file (``Fname.PLT``) for use
+        in the ``DISPLAY`` program.
 
         Two components may be selected for the summary of electromagnetic
-        forces (see FMAGSUM), two for power loss, and one each for stored
-        energy (see SENERGY) and total current (see CURR2D).  See the
+        forces (see ``FMAGSUM``), two for power loss, and one each for stored
+        energy (see ``SENERGY``) and total current (see ``CURR2D``).  See the
         referenced commands for other restrictions.
 
         PMGTRAN is restricted to MKSA units.
@@ -197,15 +197,15 @@ class Special:
         spectype
             Defines the type of response spectrum to be calculated:
 
-            0 or 1 - Displacement (relative to base excitation)
+            * ``0`` or ``1`` - Displacement (relative to base excitation)
 
-            2 - Velocity (relative to base excitation)
+            * ``2`` - Velocity (relative to base excitation)
 
-            3 - Acceleration response spectrum (absolute)
+            * ``3`` - Acceleration response spectrum (absolute)
 
-            4 - Pseudo-velocity
+            * ``4`` - Pseudo-velocity
 
-            5 - Pseudo-acceleration
+            * ``5`` - Pseudo-acceleration
 
         dampratio
             Ratio of viscous damping to critical damping (input as a decimal
@@ -224,9 +224,9 @@ class Special:
         inputtype
             Defines the type of the input time-history:
 
-            0 - Displacement (default)
+            * ``0`` - Displacement (default)
 
-            1 - Acceleration
+            * ``1`` - Acceleration
 
         Notes
         -----
@@ -235,24 +235,24 @@ class Special:
         defined as the maximum response of single degree of freedom systems of
         varying frequency (or period) to a given input support excitation.
 
-        A response spectrum analysis (ANTYPE, SPECTR with SPOPT, SPRS or MPRS)
+        A response spectrum analysis (``ANTYPE, SPECTR`` with ``SPOPT``, ``SPRS`` or ``MPRS``)
         requires a response spectrum input. This input can be determined from
         the response spectrum printout or display of this command.
 
         If a response spectrum is to be calculated from a given displacement
         (or acceleration) time-history, the displacement time-history may be
         input to a single one-element reduced linear transient dynamic
-        (ANTYPE,TRANS) analysis, so that the calculated output (which should be
+        (``ANTYPE,TRANS``) analysis, so that the calculated output (which should be
         the same as the input) will be properly located on the file.
 
-        The integration time step (argument DTIME on the RESP command) and the
+        The integration time step (argument ``DTIME`` on the RESP command) and the
         damping coefficient (argument dampRatio) are constant over the
         frequency range. The number of calculations done per response spectrum
-        curve is the product of the number of input solution points (TMAX-
-        TMIN)/DTIME and the number of frequency points (frequencies located in
+        curve is the product of the number of input solution points ``(TMAX-
+        TMIN)/DTIME`` and the number of frequency points (frequencies located in
         variable LFTAB).
 
-        Input solution points requested (using DTIME and the frequency range)
+        Input solution points requested (using ``DTIME`` and the frequency range)
         at a time not corresponding to an actual displacement solution time on
         the file are linearly interpolated with respect to the existing points.
 
@@ -279,24 +279,24 @@ class Special:
 
         ia, ib
             Reference numbers of the two variables to be operated on.  If only
-            one, leave IB blank.
+            one, leave ``IB`` blank.
 
         itype
             Defines the type of response PSD to be calculated:
 
-            0,1 - Displacement (default).
+            * ``0,1`` - Displacement (default).
 
-            2 - Velocity.
+            * ``2`` - Velocity.
 
-            3 - Acceleration.
+            * ``3`` - Acceleration.
 
         datum
             Defines the reference with respect to which response PSD is to be
             calculated:
 
-            1 - Absolute value.
+            * ``1`` - Absolute value.
 
-            2 - Relative to base (default).
+            * ``2`` - Relative to base (default).
 
         name
             Thirty-two character name identifying variable on listings and
@@ -304,12 +304,12 @@ class Special:
 
         signif
             Combine only those modes whose significance level exceeds the
-            SIGNIF threshold. The significance level is defined as the modal
+            ``SIGNIF`` threshold. The significance level is defined as the modal
             covariance matrix term divided by the maximum of all the modal
             covariance matrix terms. Any term whose significance level is less
-            than SIGNIF is considered insignificant and does not contribute to
-            the response. All modes are taken into account by default (SIGNIF =
-            0.0).
+            than ``SIGNIF`` is considered insignificant and does not contribute to
+            the response. All modes are taken into account by default (``SIGNIF =
+            0.0``).
 
         Notes
         -----
@@ -346,12 +346,12 @@ class Special:
         vect1
             Name of the first vector that contains the noisy data set (i.e.,
             independent variable). You must create and fill this vector before
-            issuing SMOOTH.
+            issuing ``SMOOTH``.
 
         vect2
             Name of the second vector that contains the dependent set of data.
             Must be the same length as the first vector. You must create and
-            fill this vector before issuing SMOOTH.
+            fill this vector before issuing ``SMOOTH``.
 
         datap
             Number of data points to be fitted, starting from the beginning of
@@ -367,18 +367,18 @@ class Special:
             order is the number of data points up to 50.  Depending on this
             number, the smoothed curve will be one of the following:
 
-            1 - Curve is the absolute average of all of the data points.
+            * ``1`` - Curve is the absolute average of all of the data points.
 
-            2 - Curve is the least square average of all of the data points.
+            * ``2`` - Curve is the least square average of all of the data points.
 
-            3 or more - Curve is a polynomial of the order (n-1), where n is the number of data fitting
+            * ``3`` or more - Curve is a polynomial of the order (n-1), where n is the number of data fitting
                         order points.
 
         vect3
             Name of the vector that contains the smoothed data of the
             independent variable. This vector should have a length equal to or
             greater than the number of smoothed data points. In batch (command)
-            mode, you must create this vector before issuing the SMOOTH
+            mode, you must create this vector before issuing the ``SMOOTH``
             command. In interactive mode, the GUI automatically creates this
             vector (if it does not exist). If you do not specify a vector name,
             the GUI will name the vector smth_ind.
@@ -387,7 +387,7 @@ class Special:
             Name of the vector that contains the smoothed data of the dependent
             variable.  This vector must be the same length as Vect3.  In batch
             (command) mode, you must create this vector before issuing the
-            SMOOTH command. In interactive mode, the GUI automatically creates
+            ``SMOOTH`` command. In interactive mode, the GUI automatically creates
             this vector (if it does not exist). If you do not specify a vector
             name, the GUI will name the vector smth_dep.
 
@@ -395,16 +395,16 @@ class Special:
             Specifies how you want to display data. No default; you must
             specify an option.
 
-            1 - Unsmoothed data only
+            * ``1`` - Unsmoothed data only
 
-            2 - Smoothed data only
+            * ``2`` - Smoothed data only
 
-            3 - Both smoothed and unsmoothed data
+            * ``3`` - Both smoothed and unsmoothed data
 
         Notes
         -----
         You can control the attributes of the graph using standard ANSYS
-        controls (/GRID, /GTHK, /COLOR, etc.). If working interactively, these
+        controls (``/GRID``, ``/GTHK``, ``/COLOR``, etc.). If working interactively, these
         controls appear in this dialog box for convenience, as well as in their
         standard dialog boxes. You must always create Vect1 and Vect2 (using
         ``*DIM``) and fill these vectors before smoothing the data. If you're
@@ -451,11 +451,11 @@ class Special:
         Notes
         -----
         Moves a variable into an array parameter vector.  The starting array
-        element number must be defined.  For example, VGET,A(1),2 moves
+        element number must be defined.  For example, ``VGET,A(1),2`` moves
         variable 2 (starting at time 0.0) to array parameter A.  Looping
-        continues from array element A(1) with the index number incremented by
+        continues from array element ``A(1)`` with the index number incremented by
         one until the variable is filled.  The number of loops may be
-        controlled with the ``*VLEN`` command (except that loop skipping (NINC) is
+        controlled with the ``*VLEN`` command (except that loop skipping (``NINC``) is
         not allowed).  For multi-dimensioned array parameters, only the first
         (row) subscript is incremented.
         """
@@ -483,9 +483,9 @@ class Special:
         kcplx
             Complex number key:
 
-            0 - Use the real part of the IR data.
+            * ``0`` - Use the real part of the IR data.
 
-            1 - Use the imaginary part of the IR data.
+            * ``1`` - Use the imaginary part of the IR data.
 
         name
             Thirty-two character name identifying the item on printouts and
@@ -494,14 +494,14 @@ class Special:
 
         Notes
         -----
-        At least one variable should be defined (NSOL, ESOL, RFORCE, etc.)
+        At least one variable should be defined (``NSOL``, ``ESOL``, ``RFORCE``, etc.)
         before using this command.  The starting array element number must be
-        defined.  For example, VPUT,A(1),2 moves array parameter A to variable
-        2 starting at time 0.0.  Looping continues from array element A(1) with
+        defined.  For example,`` VPUT,A(1),2`` moves array parameter A to variable
+        2 starting at time 0.0.  Looping continues from array element ``A(1)`` with
         the index number incremented by one until the variable is filled.
         Unfilled variable locations are assigned a zero value.  The number of
         loops may be controlled with the ``*VLEN`` command (except that loop
-        skipping (NINC) is not allowed).  For multi-dimensioned array
+        skipping (``NINC``) is not allowed).  For multi-dimensioned array
         parameters, only the first (row) subscript is incremented.
         """
         command = f"VPUT,{par},{ir},{tstrt},{kcplx},{name}"
