@@ -427,132 +427,6 @@ class Database:
         command = "CHECK,%s,%s" % (str(sele), str(levl))
         return self.run(command, **kwargs)
 
-    def cncheck(
-        self,
-        option="",
-        rid1="",
-        rid2="",
-        rinc="",
-        intertype="",
-        trlevel="",
-        cgap="",
-        cpen="",
-        ioff="",
-        **kwargs,
-    ):
-        """Provides and/or adjusts the initial status of contact pairs.
-
-        APDL Command: CNCHECK
-
-        Parameters
-        ----------
-        option
-            Option to be performed:
-
-            DETAIL - List all contact pair properties (default).
-
-            SUMMARY - List only the open/closed status for each contact pair.
-
-            POST - Execute a partial solution to write the initial
-                   contact configuration to the Jobname.RCN file.
-
-            ADJUST - Physically move contact nodes to the target in
-                     order to close a gap or reduce penetration. The
-                     initial adjustment is converted to structural
-                     displacement values (UX, UY, UZ) and stored in
-                     the Jobname.RCN file.
-
-            RESET - Reset target element and contact element key
-                    options and real constants to their default
-                    values. This option is not valid for general
-                    contact.
-
-            AUTO - Automatically sets certain real constants and key
-                   options to recommended values or settings in order
-                   to achieve better convergence based on overall
-                   contact pair behaviors. This option is not valid
-                   for general contact.
-
-            TRIM - Trim contact pair (remove certain contact and target elements).
-
-            UNSE - Unselect certain contact and target elements.
-
-        rid1, rid2, rinc
-            For pair-based contact, the range of real constant pair
-            ID's for which Option will be performed. If RID2 is not
-            specified, it defaults to RID1. If no value is specified,
-            all contact pairs in the selected set of elements are
-            considered.
-
-        intertype
-            The type of contact interface (pair-based versus general
-            contact) to be considered; or the type of contact pair to
-            be trimmed/unselected/auto-set.
-
-            (blank) - Include all contact definitions (pair-based and general contact).
-
-            GCN - Include general contact definitions only (not valid
-                  when Option = RESET or AUTO).
-
-        trlevel
-            Trimming level (used only when Option = TRIM or UNSE):
-
-            (blank) - Normal trimming (default): remove/unselect
-                      contact and target elements which are in
-                      far-field.
-
-            AGGRE - Aggressive trimming: remove/unselect contact and
-                    target elements which are in far-field, and
-                    certain elements in near-field.
-
-        Notes
-        -----
-        The CNCHECK command provides information for
-        surface-to-surface, node- to-surface, and line-to-line contact
-        pairs (element types TARGE169, TARGE170, CONTA171, CONTA172,
-        CONTA173, CONTA174, CONTA175, CONTA176, CONTA177). All contact
-        and target elements of interest, along with the solid elements
-        and nodes attached to them, must be selected for the command
-        to function properly. For performance reasons, the program
-        uses a subset of nodes and elements based on the specified
-        contact regions (RID1, RID2, RINC) when executing the CNCHECK
-        command.
-
-        CNCHECK is available in both the PREP7 and SOLUTION
-        processors, but only before the first solve operation (that
-        is, only before the first load step or the first substep).
-
-        If the contact and target elements were generated through mesh
-        commands (AMESH, LMESH, etc.) instead of the ESURF command,
-        you must issue MODMSH,DETACH before CNCHECK. Otherwise,
-        CNCHECK will not work correctly.
-
-        The following additional notes are available:
-
-        The command CNCHECK,POST solves the initial contact configuration in
-        one substep. After issuing this command, you can postprocess the
-        contact result items as you would for any other converged load step;
-        however, only the contact status, contact penetration or gap, and
-        contact pressure will have meaningful values. Other contact quantities
-        (friction stress, sliding distance, chattering) will be available but
-        are not useful.
-
-        Because Option = POST forces a solve operation, the PrepPost (PP)
-        license does not work with CNCHECK,POST.
-        """
-        command = "CNCHECK,%s,%s,%s,%s,%s,%s,%s,%s,%s" % (
-            str(option),
-            str(rid1),
-            str(rid2),
-            str(rinc),
-            str(intertype),
-            str(trlevel),
-            str(cgap),
-            str(cpen),
-            str(ioff),
-        )
-        return self.run(command, **kwargs)
-
     def igesout(self, fname="", ext="", att="", **kwargs):
         """Writes solid model data to a file in IGES Version 5.1 format.
 
